@@ -2,7 +2,5 @@ import std_msgs.msg
 
 s = std_msgs.msg.String()
 
-print "<<< a >>>"
-print type(s)
-
-
+print("<<< a >>>")
+print(type(s))
